# Estimation

```{eval-rst}
.. autoclass:: openpkpd.estimation.base.EstimationResult
   :members:
   :undoc-members: False
```

```{eval-rst}
.. autoclass:: openpkpd.estimation.base.EstimationMethod
   :members:
   :undoc-members: False
```
